aboutsummaryrefslogtreecommitdiff
path: root/src/patch/test_patch_system.cc
diff options
context:
space:
mode:
authorjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2002-08-01 15:08:44 +0000
committerjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2002-08-01 15:08:44 +0000
commit2f003912c98ddc2c351b23eda6d8d45c63f2d184 (patch)
treec510d4432a649614454554fd549bef035a2b16b2 /src/patch/test_patch_system.cc
parentc8a99083b91220ba9e1bb93a2318ed60ab70a01d (diff)
rename test_synchronize_Jacobians() --> test_ghost_zone_Jacobian()
to make it clearer what the test does -- also change parameter accordingly git-svn-id: http://svn.einsteintoolkit.org/cactus/EinsteinAnalysis/AHFinderDirect/trunk@681 f88db872-0e4f-0410-b76b-b9085cfa78c5
Diffstat (limited to 'src/patch/test_patch_system.cc')
-rw-r--r--src/patch/test_patch_system.cc16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/patch/test_patch_system.cc b/src/patch/test_patch_system.cc
index 27fe933..d4579df 100644
--- a/src/patch/test_patch_system.cc
+++ b/src/patch/test_patch_system.cc
@@ -6,7 +6,7 @@
// <<<prototypes>>>
//
// driver - Cactus interface
/// test_synchronize_Jacobians - test Jacobian of ghost zone synchronization ops
//
/// verify_gpn - verify gpn <--> (patch,irho,isigma) conversions
///
@@ -101,7 +101,7 @@ extern "C"
void test_patch_system(CCTK_ARGUMENTS);
namespace {
-void test_synchronize_Jacobians(patch_system& ps,
+void test_ghost_zone_Jacobians(patch_system& ps,
int test_gfn, int NP_test_gfn,
fp perturbation_amplitude,
bool perturb_all_y_patch_points,
@@ -208,10 +208,10 @@ else if (STRING_EQUAL(which_test, "synchronize"))
ps.print_ghosted_gridfn(ghosted_error_gfn, "ghosted_error.dat");
}
-else if (STRING_EQUAL(which_test, "synchronize Jacobian"))
+else if (STRING_EQUAL(which_test, "ghost zone Jacobian"))
then {
verify_gpn(ps);
- test_synchronize_Jacobians(ps,
+ test_ghost_zone_Jacobians(ps,
test_fn_gfn, test_fn_copy_gfn,
NP_Jacobian__perturbation_amplitude,
(NP_Jacobian__perturb_all_y_patch_points != 0),
@@ -246,7 +246,7 @@ CCTK_VInfo(CCTK_THORNSTRING, "destroying patch system");
//
// This function tests the computation of the Jacobian of the
// patch_system::synchronize() operation. In outline, it does the following:
//
// set up a test function in test_gfn on the nominal grid
// synchronize test_gfn
@@ -301,13 +301,13 @@ CCTK_VInfo(CCTK_THORNSTRING, "destroying patch system");
// should be written.
//
namespace {
-void test_synchronize_Jacobians(patch_system& ps,
+void test_ghost_zone_Jacobians(patch_system& ps,
int test_gfn, int NP_test_gfn,
fp perturbation_amplitude,
bool perturb_all_y_patch_points,
const char Jacobian_file_name[])
{
-CCTK_VInfo(CCTK_THORNSTRING, "testing synchronize() Jacobian...");
+CCTK_VInfo(CCTK_THORNSTRING, "testing ghost zone synchronize() Jacobian...");
setup_sym_fn_xyz(ps, test_gfn, false);
ps.synchronize(test_fn_gfn, test_fn_gfn);
@@ -318,7 +318,7 @@ setup_sym_fn_xyz(ps, NP_test_gfn, false);
FILE *fileptr = fopen(Jacobian_file_name, "w");
if (fileptr == NULL)
then CCTK_VWarn(-1, __LINE__, __FILE__, CCTK_THORNSTRING,
-"test_synchronize_Jacobians(): can't open output plot file \"%s\"!",
+"test_ghost_zone_Jacobians(): can't open output plot file \"%s\"!",
Jacobian_file_name); /*NOTREACHED*/
fprintf(fileptr, "# column 1 = x patch number\n");
fprintf(fileptr, "# column 2 = x ghost_zone is_min()\n");
@@ -6,7 +6,7 @@
//
// driver - Cactus interface
-/// test_synchronize_Jacobians - test Jacobian of ghost zone synchronization ops
+/// test_ghost_zone_Jacobians - test Jacobian of ghost zone synchronization ops
//
/// verify_gpn - verify gpn <--> (patch,irho,isigma) conversions
@@ -246,7 +246,7 @@ CCTK_VInfo(CCTK_THORNSTRING, "destroying patch system");
//
// This function tests the computation of the Jacobian of the
-// patch_system::synchronize() operation. In outline, it does the following:
+// ghost_zone::synchronize() operation. In outline, it does the following:
//
// set up a test function in test_gfn on the nominal grid